@@ -1,16 +1,17 @@
 
-use cassandra::future::ConnectFuture;
+use cassandra::future::CassFuture;
 use cassandra::policy::retry::RetryPolicy;
 use cassandra::session::Session;
 use cassandra::ssl::Ssl;
 use cassandra::time::TimestampGen;
 use cassandra::util::Protected;
+use cassandra::error::*;
+
 use cassandra_sys::CassCluster as _Cluster;
 use cassandra_sys::cass_bool_t;
 use cassandra_sys::cass_cluster_free;
 use cassandra_sys::cass_cluster_new;
 use cassandra_sys::cass_cluster_set_connect_timeout;
-
 use cassandra_sys::cass_cluster_set_connection_heartbeat_interval;
 use cassandra_sys::cass_cluster_set_connection_idle_timeout;
 use cassandra_sys::cass_cluster_set_contact_points;
@@ -48,50 +49,22 @@ use cassandra_sys::cass_future_error_code;
 use cassandra_sys::cass_session_connect;
 use cassandra_sys::cass_session_new;
 use cassandra_sys::cass_true;
-use errors::*;
+
 // use ip::IpAddr;
-use errors::*;
-use std::ffi::CString;
+use std::ffi::{CString, CStr};
 use std::ffi::NulError;
 use std::fmt;
 use std::iter::Map;
 use std::net::AddrParseError;
 use std::net::Ipv4Addr;
-
 use std::result;
+use std::fmt::Display;
 use std::str::FromStr;
 use time::Duration;
+use futures::Future;
 
-/// Possible Cql Protocol versions
-#[allow(missing_docs)]
-pub enum CqlProtocol {
-    ONE = 1,
-    TWO = 2,
-    THREE = 3,
-    FOUR = 4,
-}
-
-/// A set of cassandra contact points
-#[derive(Debug)]
-pub struct ContactPoints(Vec<Ipv4Addr>);
-
-impl fmt::Display for ContactPoints {
-    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        let contact_points: Vec<String> = self.0.iter().map(|ip| format!("{}", ip)).collect();
-        write!(f, "{} ", contact_points.join(","))
-    }
-}
-
-impl FromStr for ContactPoints {
-    type Err = Error;
-    fn from_str(s: &str) -> Result<Self> {
-        let points: Vec<&str> = s.split(',').collect();
-        let contact_points: result::Result<Vec<Ipv4Addr>, AddrParseError> = points.iter()
-            .map(|addr| Ipv4Addr::from_str(addr))
-            .collect();
-        Ok(ContactPoints(contact_points.unwrap()))
-    }
-}
+/// A CQL protocol version is just an integer.
+pub type CqlProtocol = i32;
 
 ///
 /// The main class to use when interacting with a Cassandra cluster.
@@ -100,11 +73,10 @@ impl FromStr for ContactPoints {
 ///
 /// # Examples
 /// ```
-/// use std::str::FromStr;
-/// use cassandra_cpp::{Cluster,ContactPoints};
+/// use cassandra_cpp::Cluster;
 /// let mut cluster = Cluster::default();
-/// cluster.set_contact_points(ContactPoints::from_str("127.0.0.1").unwrap()).unwrap();
-/// let mut session = cluster.connect().unwrap();
+/// cluster.set_contact_points("127.0.0.1").unwrap();
+/// let _session = cluster.connect().unwrap();
 /// ```
 #[derive(Debug)]
 pub struct Cluster(pub *mut _Cluster);
@@ -134,11 +106,11 @@ impl Cluster {
     /// {contact points: "127.0.0.1" "127.0.0.1,127.0.0.2", "server1.domain.com"}
     ///
     ///
-    pub fn set_contact_points<T: Into<ContactPoints>>(&mut self, contact_points: T) -> Result<&mut Self> {
+    pub fn set_contact_points(&mut self, contact_points: &str) -> Result<&mut Self> {
         unsafe {
-            let s = CString::new(contact_points.into().to_string()).expect("must be utf8");
+            let s = CString::new(contact_points.clone())?;
             let err = cass_cluster_set_contact_points(self.0, s.as_ptr());
-            err.to_result(self).chain_err(|| "Could not set contact points")
+            err.to_result(self)
         }
     }
 
@@ -149,7 +121,7 @@ impl Cluster {
     /// Default: 9042
     ///
     pub fn set_port(&mut self, port: u16) -> Result<&mut Self> {
-        unsafe { cass_cluster_set_port(self.0, port as i32).to_result(self).chain_err(|| "Could not set port") }
+        unsafe { cass_cluster_set_port(self.0, port as i32).to_result(self) }
     }
 
 
@@ -165,8 +137,8 @@ impl Cluster {
     pub fn connect(&mut self) -> Result<Session> {
         unsafe {
             let session = Session(cass_session_new());
-            let connect_future = ConnectFuture::build(cass_session_connect(session.0, self.0));
-            cass_future_error_code(connect_future.inner()).to_result(session).chain_err(|| "Could not connect")
+            let connect_future = <CassFuture<()>>::build(cass_session_connect(session.0, self.0));
+            connect_future.wait().map(|_| session)
         }
     }
 
@@ -180,7 +152,6 @@ impl Cluster {
         unsafe {
             cass_cluster_set_protocol_version(self.0, protocol_version as i32)
                 .to_result(self)
-                .chain_err(|| "Couldn't set protocol version")
         }
     }
 
@@ -194,7 +165,6 @@ impl Cluster {
         unsafe {
             cass_cluster_set_num_threads_io(self.0, num_threads)
                 .to_result(self)
-                .chain_err(|| "couldn't set thread count")
         }
     }
 
@@ -207,7 +177,6 @@ impl Cluster {
         unsafe {
             cass_cluster_set_queue_size_io(self.0, queue_size)
                 .to_result(self)
-                .chain_err(|| "couldn't set io queue size")
         }
     }
 
@@ -220,7 +189,6 @@ impl Cluster {
         unsafe {
             cass_cluster_set_queue_size_event(self.0, queue_size)
                 .to_result(self)
-                .chain_err(|| "couldn't set event queue size")
         }
     }
 
@@ -234,7 +202,6 @@ impl Cluster {
         unsafe {
             cass_cluster_set_core_connections_per_host(self.0, num_connections)
                 .to_result(self)
-                .chain_err(|| "couldn't set connections per host")
         }
     }
 
@@ -248,7 +215,6 @@ impl Cluster {
         unsafe {
             cass_cluster_set_max_connections_per_host(self.0, num_connections)
                 .to_result(self)
-                .chain_err(|| "couldn't set max connections per host")
         }
     }
 
@@ -274,7 +240,6 @@ impl Cluster {
         unsafe {
             cass_cluster_set_max_concurrent_creation(self.0, num_connections)
                 .to_result(self)
-                .chain_err(|| "couldn't set max_concurrent_creation")
         }
     }
 
@@ -288,7 +253,6 @@ impl Cluster {
         unsafe {
             cass_cluster_set_max_concurrent_requests_threshold(self.0, num_requests)
                 .to_result(self)
-                .chain_err(|| "couldn't set max concurrend requests threshold")
         }
     }
 
@@ -301,7 +265,6 @@ impl Cluster {
         unsafe {
             cass_cluster_set_max_requests_per_flush(self.0, num_requests)
                 .to_result(self)
-                .chain_err(|| "couldn't set max requests per flush")
         }
     }
 
@@ -315,7 +278,6 @@ impl Cluster {
         unsafe {
             cass_cluster_set_write_bytes_high_water_mark(self.0, num_bytes)
                 .to_result(self)
-                .chain_err(|| "couldn't set write bytes high water mark")
         }
     }
 
@@ -329,7 +291,6 @@ impl Cluster {
         unsafe {
             cass_cluster_set_write_bytes_low_water_mark(self.0, num_bytes)
                 .to_result(self)
-                .chain_err(|| "couldn't set write bytes low water mark")
         }
     }
 
@@ -344,7 +305,6 @@ impl Cluster {
         unsafe {
             cass_cluster_set_pending_requests_high_water_mark(self.0, num_requests)
                 .to_result(self)
-                .chain_err(|| "couldn't set pending requests high water mark")
         }
     }
 
@@ -359,7 +319,6 @@ impl Cluster {
         unsafe {
             cass_cluster_set_pending_requests_low_water_mark(self.0, num_requests)
                 .to_result(self)
-                .chain_err(|| "couldn't set pending requests low water mark")
         }
     }
 
@@ -388,11 +347,11 @@ impl Cluster {
     }
 
     /// Sets credentials for plain text authentication.
-    pub fn set_credentials(&mut self, username: &str, password: &str) -> Result<&Self> {
+    pub fn set_credentials(&mut self, username: &str, password: &str) -> Result<&mut Self> {
         unsafe {
             cass_cluster_set_credentials(self.0,
-                                         CString::new(username).chain_err(|| "username not a valid CString")?.as_ptr(),
-                                         CString::new(password).chain_err(|| "password not a valid CString")?.as_ptr());
+                                         CString::new(username)?.as_ptr(),
+                                         CString::new(password)?.as_ptr());
         }
         Ok(self)
     }
@@ -424,14 +383,13 @@ impl Cluster {
                                         -> Result<&mut Self> {
         unsafe {
             {
-                    let local_dc = CString::new(local_dc).expect("must be utf8");
+                    let local_dc = CString::new(local_dc)?;
                     cass_cluster_set_load_balance_dc_aware(self.0,
                                                            local_dc.as_ptr(),
                                                            used_hosts_per_remote_dc,
                                                            allow_remote_dcs_for_local_cl)
                 }
                 .to_result(self)
-                .chain_err(|| "couldn't set dc aware load balancing policy")
         }
     }
 
@@ -511,7 +469,6 @@ impl Cluster {
     ///
     /// Examples: "127.0.0.1" "127.0.0.1,127.0.0.2", "server1.domain.com"
     pub fn set_whitelist_filtering(&mut self, hosts: Vec<String>) -> &Self {
-        // FIXME replace host strings with InetSomethings
         unsafe {
             cass_cluster_set_whitelist_filtering(self.0, hosts.join(",").as_ptr() as *const i8);
         }
