@@ -1,12 +1,12 @@
 use cassandra::data_type::ConstDataType;
 use cassandra::data_type::DataType;
-
-use cassandra::error::CassError;
 use cassandra::inet::Inet;
 use cassandra::tuple::Tuple;
 use cassandra::user_type::UserType;
 use cassandra::util::Protected;
 use cassandra::uuid::Uuid;
+use cassandra::error::*;
+
 use cassandra_sys::CASS_COLLECTION_TYPE_LIST;
 use cassandra_sys::CASS_COLLECTION_TYPE_MAP;
 use cassandra_sys::CASS_COLLECTION_TYPE_SET;
@@ -14,7 +14,6 @@ use cassandra_sys::CassCollection as _CassCollection;
 use cassandra_sys::cass_collection_append_bool;
 use cassandra_sys::cass_collection_append_bytes;
 use cassandra_sys::cass_collection_append_collection;
-#[allow(unused_imports)]
 use cassandra_sys::cass_collection_append_decimal;
 use cassandra_sys::cass_collection_append_double;
 use cassandra_sys::cass_collection_append_float;
@@ -34,7 +33,7 @@ use cassandra_sys::cass_collection_new;
 use cassandra_sys::cass_collection_new_from_data_type;
 use cassandra_sys::cass_false;
 use cassandra_sys::cass_true;
-use errors::*;
+
 use std::ffi::CString;
 
 // #[repr(C)]
@@ -154,38 +153,38 @@ impl CassCollection for List {
 
     /// Appends a "tinyint" to the collection.
     fn append_int8(&mut self, value: i8) -> Result<&mut Self> {
-        unsafe { cass_collection_append_int8(self.inner(), value).to_result(self).chain_err(|| "couldn't append i8") }
+        unsafe { cass_collection_append_int8(self.inner(), value).to_result(self) }
     }
 
     /// Appends an "smallint" to the collection.
     fn append_int16(&mut self, value: i16) -> Result<&mut Self> {
-        unsafe { cass_collection_append_int16(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_int16(self.inner(), value).to_result(self) }
     }
 
     /// Appends an "int" to the collection.
     fn append_int32(&mut self, value: i32) -> Result<&mut Self> {
-        unsafe { cass_collection_append_int32(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_int32(self.inner(), value).to_result(self) }
     }
 
     /// Appends a "date" to the collection.
     fn append_uint32(&mut self, value: u32) -> Result<&mut Self> {
-        unsafe { cass_collection_append_uint32(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_uint32(self.inner(), value).to_result(self) }
     }
 
     /// Appends a "bigint", "counter", "timestamp" or "time" to the
     /// collection.
     fn append_int64(&mut self, value: i64) -> Result<&mut Self> {
-        unsafe { cass_collection_append_int64(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_int64(self.inner(), value).to_result(self) }
     }
 
     /// Appends a "float" to the collection.
     fn append_float(&mut self, value: f32) -> Result<&mut Self> {
-        unsafe { cass_collection_append_float(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_float(self.inner(), value).to_result(self) }
     }
 
     /// Appends a "double" to the collection.
     fn append_double(&mut self, value: f64) -> Result<&mut Self> {
-        unsafe { cass_collection_append_double(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_double(self.inner(), value).to_result(self) }
     }
 
     /// Appends a "boolean" to the collection.
@@ -193,16 +192,15 @@ impl CassCollection for List {
         unsafe {
             cass_collection_append_bool(self.inner(), if value { cass_true } else { cass_false })
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
     /// Appends an "ascii", "text" or "varchar" to the collection.
     fn append_string(&mut self, value: &str) -> Result<&mut Self> {
         unsafe {
-            let cstr = CString::new(value).expect("must be utf8");
+            let cstr = CString::new(value)?;
             let result = cass_collection_append_string(self.inner(), cstr.as_ptr());
-            result.to_result(self).chain_err(|| "")
+            result.to_result(self)
         }
     }
 
@@ -210,43 +208,43 @@ impl CassCollection for List {
     fn append_bytes(&mut self, value: Vec<u8>) -> Result<&mut Self> {
         unsafe {
             let bytes = cass_collection_append_bytes(self.inner(), value[..].as_ptr(), value.len());
-            bytes.to_result(self).chain_err(|| "")
+            bytes.to_result(self)
         }
     }
 
     /// Appends a "uuid" or "timeuuid"  to the collection.
     fn append_uuid(&mut self, value: Uuid) -> Result<&mut Self> {
-        unsafe { cass_collection_append_uuid(self.inner(), value.inner()).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_uuid(self.inner(), value.inner()).to_result(self) }
     }
 
     /// Appends an "inet" to the collection.
     fn append_inet(&mut self, value: Inet) -> Result<&mut Self> {
-        unsafe { cass_collection_append_inet(self.inner(), value.inner()).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_inet(self.inner(), value.inner()).to_result(self) }
     }
 
     /// Appends a "list" to the collection.
     fn append_list(&mut self, value: List) -> Result<&mut Self> {
-        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self) }
     }
 
     /// Appends a "set" to the collection.
     fn append_set(&mut self, value: Set) -> Result<&mut Self> {
-        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self) }
     }
 
     /// Appends a "map" to the collection.
     fn append_map(&mut self, value: Map) -> Result<&mut Self> {
-        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self) }
     }
 
     /// Appends a "tuple" to the collection.
     fn append_tuple(&mut self, value: Tuple) -> Result<&mut Self> {
-        unsafe { cass_collection_append_tuple(self.inner(), value.inner()).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_tuple(self.inner(), value.inner()).to_result(self) }
     }
 
     /// Appends a "udt" to the collection.
     fn append_user_type(&mut self, value: &UserType) -> Result<&mut Self> {
-        unsafe { cass_collection_append_user_type(self.inner(), value.inner()).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_user_type(self.inner(), value.inner()).to_result(self) }
     }
 }
 
@@ -279,38 +277,38 @@ impl CassCollection for Set {
 
     /// Appends a "tinyint" to the collection.
     fn append_int8(&mut self, value: i8) -> Result<&mut Self> {
-        unsafe { cass_collection_append_int8(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_int8(self.inner(), value).to_result(self) }
     }
 
     /// Appends an "smallint" to the collection.
     fn append_int16(&mut self, value: i16) -> Result<&mut Self> {
-        unsafe { cass_collection_append_int16(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_int16(self.inner(), value).to_result(self) }
     }
 
     /// Appends an "int" to the collection.
     fn append_int32(&mut self, value: i32) -> Result<&mut Self> {
-        unsafe { cass_collection_append_int32(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_int32(self.inner(), value).to_result(self) }
     }
 
     /// Appends a "date" to the collection.
     fn append_uint32(&mut self, value: u32) -> Result<&mut Self> {
-        unsafe { cass_collection_append_uint32(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_uint32(self.inner(), value).to_result(self) }
     }
 
     /// Appends a "bigint", "counter", "timestamp" or "time" to the
     /// collection.
     fn append_int64(&mut self, value: i64) -> Result<&mut Self> {
-        unsafe { cass_collection_append_int64(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_int64(self.inner(), value).to_result(self) }
     }
 
     /// Appends a "float" to the collection.
     fn append_float(&mut self, value: f32) -> Result<&mut Self> {
-        unsafe { cass_collection_append_float(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_float(self.inner(), value).to_result(self) }
     }
 
     /// Appends a "double" to the collection.
     fn append_double(&mut self, value: f64) -> Result<&mut Self> {
-        unsafe { cass_collection_append_double(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_double(self.inner(), value).to_result(self) }
     }
 
     /// Appends a "boolean" to the collection.
@@ -318,16 +316,15 @@ impl CassCollection for Set {
         unsafe {
             cass_collection_append_bool(self.inner(), if value { cass_true } else { cass_false })
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
     /// Appends an "ascii", "text" or "varchar" to the collection.
     fn append_string(&mut self, value: &str) -> Result<&mut Self> {
         unsafe {
-            let cstr = CString::new(value).expect("must be utf8");
+            let cstr = CString::new(value)?;
             let result = cass_collection_append_string(self.inner(), cstr.as_ptr());
-            result.to_result(self).chain_err(|| "")
+            result.to_result(self)
         }
     }
 
@@ -335,43 +332,43 @@ impl CassCollection for Set {
     fn append_bytes(&mut self, value: Vec<u8>) -> Result<&mut Self> {
         unsafe {
             let bytes = cass_collection_append_bytes(self.inner(), value[..].as_ptr(), value.len());
-            bytes.to_result(self).chain_err(|| "")
+            bytes.to_result(self)
         }
     }
 
     /// Appends a "uuid" or "timeuuid"  to the collection.
     fn append_uuid(&mut self, value: Uuid) -> Result<&mut Self> {
-        unsafe { cass_collection_append_uuid(self.inner(), value.inner()).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_uuid(self.inner(), value.inner()).to_result(self) }
     }
 
     /// Appends an "inet" to the collection.
     fn append_inet(&mut self, value: Inet) -> Result<&mut Self> {
-        unsafe { cass_collection_append_inet(self.inner(), value.inner()).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_inet(self.inner(), value.inner()).to_result(self) }
     }
 
     /// Appends a "list" to the collection.
     fn append_list(&mut self, value: List) -> Result<&mut Self> {
-        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self) }
     }
 
     /// Appends a "set" to the collection.
     fn append_set(&mut self, value: Set) -> Result<&mut Self> {
-        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self) }
     }
 
     /// Appends a "map" to the collection.
     fn append_map(&mut self, value: Map) -> Result<&mut Self> {
-        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self) }
     }
 
     /// Appends a "tuple" to the collection.
     fn append_tuple(&mut self, value: Tuple) -> Result<&mut Self> {
-        unsafe { cass_collection_append_tuple(self.inner(), value.inner()).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_tuple(self.inner(), value.inner()).to_result(self) }
     }
 
     /// Appends a "udt" to the collection.
     fn append_user_type(&mut self, value: &UserType) -> Result<&mut Self> {
-        unsafe { cass_collection_append_user_type(self.inner(), value.inner()).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_user_type(self.inner(), value.inner()).to_result(self) }
     }
 }
 
@@ -401,38 +398,38 @@ impl CassCollection for Map {
 
     /// Appends a "tinyint" to the collection.
     fn append_int8(&mut self, value: i8) -> Result<&mut Self> {
-        unsafe { cass_collection_append_int8(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_int8(self.inner(), value).to_result(self) }
     }
 
     /// Appends an "smallint" to the collection.
     fn append_int16(&mut self, value: i16) -> Result<&mut Self> {
-        unsafe { cass_collection_append_int16(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_int16(self.inner(), value).to_result(self) }
     }
 
     /// Appends an "int" to the collection.
     fn append_int32(&mut self, value: i32) -> Result<&mut Self> {
-        unsafe { cass_collection_append_int32(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_int32(self.inner(), value).to_result(self) }
     }
 
     /// Appends a "date" to the collection.
     fn append_uint32(&mut self, value: u32) -> Result<&mut Self> {
-        unsafe { cass_collection_append_uint32(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_uint32(self.inner(), value).to_result(self) }
     }
 
     /// Appends a "bigint", "counter", "timestamp" or "time" to the
     /// collection.
     fn append_int64(&mut self, value: i64) -> Result<&mut Self> {
-        unsafe { cass_collection_append_int64(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_int64(self.inner(), value).to_result(self) }
     }
 
     /// Appends a "float" to the collection.
     fn append_float(&mut self, value: f32) -> Result<&mut Self> {
-        unsafe { cass_collection_append_float(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_float(self.inner(), value).to_result(self) }
     }
 
     /// Appends a "double" to the collection.
     fn append_double(&mut self, value: f64) -> Result<&mut Self> {
-        unsafe { cass_collection_append_double(self.inner(), value).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_double(self.inner(), value).to_result(self) }
     }
 
     /// Appends a "boolean" to the collection.
@@ -440,16 +437,15 @@ impl CassCollection for Map {
         unsafe {
             cass_collection_append_bool(self.inner(), if value { cass_true } else { cass_false })
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
     /// Appends an "ascii", "text" or "varchar" to the collection.
     fn append_string(&mut self, value: &str) -> Result<&mut Self> {
         unsafe {
-            let cstr = CString::new(value).expect("must be utf8");
+            let cstr = CString::new(value)?;
             let result = cass_collection_append_string(self.inner(), cstr.as_ptr());
-            result.to_result(self).chain_err(|| "")
+            result.to_result(self)
         }
     }
 
@@ -457,42 +453,42 @@ impl CassCollection for Map {
     fn append_bytes(&mut self, value: Vec<u8>) -> Result<&mut Self> {
         unsafe {
             let bytes = cass_collection_append_bytes(self.inner(), value[..].as_ptr(), value.len());
-            bytes.to_result(self).chain_err(|| "")
+            bytes.to_result(self)
         }
     }
 
     /// Appends a "uuid" or "timeuuid"  to the collection.
     fn append_uuid(&mut self, value: Uuid) -> Result<&mut Self> {
-        unsafe { cass_collection_append_uuid(self.inner(), value.inner()).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_uuid(self.inner(), value.inner()).to_result(self) }
     }
 
     /// Appends an "inet" to the collection.
     fn append_inet(&mut self, value: Inet) -> Result<&mut Self> {
-        unsafe { cass_collection_append_inet(self.inner(), value.inner()).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_inet(self.inner(), value.inner()).to_result(self) }
     }
 
     /// Appends a "list" to the collection.
     fn append_list(&mut self, value: List) -> Result<&mut Self> {
-        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self) }
     }
 
     /// Appends a "set" to the collection.
     fn append_set(&mut self, value: Set) -> Result<&mut Self> {
-        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self) }
     }
 
     /// Appends a "map" to the collection.
     fn append_map(&mut self, value: Map) -> Result<&mut Self> {
-        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_collection(self.inner(), value.0).to_result(self) }
     }
 
     /// Appends a "tuple" to the collection.
     fn append_tuple(&mut self, value: Tuple) -> Result<&mut Self> {
-        unsafe { cass_collection_append_tuple(self.inner(), value.inner()).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_tuple(self.inner(), value.inner()).to_result(self) }
     }
 
     /// Appends a "udt" to the collection.
     fn append_user_type(&mut self, value: &UserType) -> Result<&mut Self> {
-        unsafe { cass_collection_append_user_type(self.inner(), value.inner()).to_result(self).chain_err(|| "") }
+        unsafe { cass_collection_append_user_type(self.inner(), value.inner()).to_result(self) }
     }
 }
