@@ -1,12 +1,12 @@
 use cassandra::collection::Set;
 use cassandra::data_type::ConstDataType;
 use cassandra::data_type::DataType;
-use cassandra::error::CassError;
-
 use cassandra::inet::AsInet;
 use cassandra::user_type::UserType;
 use cassandra::util::Protected;
 use cassandra::uuid::Uuid;
+use cassandra::error::*;
+
 use cassandra_sys::CassTuple as _Tuple;
 use cassandra_sys::cass_false;
 use cassandra_sys::cass_true;
@@ -17,7 +17,6 @@ use cassandra_sys::cass_tuple_new_from_data_type;
 use cassandra_sys::cass_tuple_set_bool;
 use cassandra_sys::cass_tuple_set_bytes;
 use cassandra_sys::cass_tuple_set_collection;
-#[allow(unused_imports)]
 use cassandra_sys::cass_tuple_set_decimal;
 use cassandra_sys::cass_tuple_set_double;
 use cassandra_sys::cass_tuple_set_float;
@@ -32,11 +31,10 @@ use cassandra_sys::cass_tuple_set_tuple;
 use cassandra_sys::cass_tuple_set_uint32;
 use cassandra_sys::cass_tuple_set_user_type;
 use cassandra_sys::cass_tuple_set_uuid;
-use errors::*;
+
 use std::ffi::CString;
 use std::net::SocketAddr;
 
-
 /// A tuple of values.
 #[derive(Debug)]
 pub struct Tuple(*mut _Tuple);
@@ -63,7 +61,6 @@ impl Tuple {
         unsafe {
             cass_tuple_set_null(self.0, index)
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
@@ -72,7 +69,6 @@ impl Tuple {
         unsafe {
             cass_tuple_set_int8(self.0, index, value)
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
@@ -81,7 +77,6 @@ impl Tuple {
         unsafe {
             cass_tuple_set_int16(self.0, index, value)
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
@@ -90,7 +85,6 @@ impl Tuple {
         unsafe {
             cass_tuple_set_int32(self.0, index, value)
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
@@ -99,7 +93,6 @@ impl Tuple {
         unsafe {
             cass_tuple_set_uint32(self.0, index, value)
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
@@ -109,7 +102,6 @@ impl Tuple {
         unsafe {
             cass_tuple_set_int64(self.0, index, value)
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
@@ -118,7 +110,6 @@ impl Tuple {
         unsafe {
             cass_tuple_set_float(self.0, index, value)
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
@@ -127,7 +118,6 @@ impl Tuple {
         unsafe {
             cass_tuple_set_double(self.0, index, value)
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
@@ -136,7 +126,6 @@ impl Tuple {
         unsafe {
             cass_tuple_set_bool(self.0, index, if value { cass_true } else { cass_false })
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
@@ -146,9 +135,8 @@ impl Tuple {
         unsafe {
             cass_tuple_set_string(self.0,
                                   index,
-                                  CString::new(value.into()).expect("must be utf8").as_ptr())
+                                  CString::new(value.into())?.as_ptr())
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
@@ -157,7 +145,6 @@ impl Tuple {
         unsafe {
             cass_tuple_set_bytes(self.0, index, value.as_ptr(), value.len())
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
@@ -167,7 +154,6 @@ impl Tuple {
         unsafe {
             cass_tuple_set_uuid(self.0, index, value.into().inner())
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
@@ -177,7 +163,6 @@ impl Tuple {
         unsafe {
             cass_tuple_set_inet(self.0, index, inet.inner())
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
@@ -187,7 +172,6 @@ impl Tuple {
         unsafe {
             cass_tuple_set_collection(self.0, index, value.into().inner())
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
@@ -196,7 +180,6 @@ impl Tuple {
         unsafe {
             cass_tuple_set_tuple(self.0, index, value.0)
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 
@@ -205,7 +188,6 @@ impl Tuple {
         unsafe {
             cass_tuple_set_user_type(self.0, index, value.inner())
                 .to_result(self)
-                .chain_err(|| "")
         }
     }
 }
